"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2018 The Bazel Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
import abc
import buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2
import collections.abc
import buildgrid.common.protos.google.longrunning.operations_pb2
import grpc.aio as grpc
import typing

class ExecutionStub:
    """The Remote Execution API is used to execute an
    [Action][build.bazel.remote.execution.v2.Action] on the remote
    workers.

    As with other services in the Remote Execution API, any call may return an
    error with a [RetryInfo][google.rpc.RetryInfo] error detail providing
    information about when the client should retry the request; clients SHOULD
    respect the information provided.
    """

    def __init__(self, channel: grpc.Channel) -> None: ...
    Execute: grpc.UnaryStreamMultiCallable[
        buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.ExecuteRequest,
        buildgrid.common.protos.google.longrunning.operations_pb2.Operation,
    ]
    """Execute an action remotely.

    In order to execute an action, the client must first upload all of the
    inputs, the
    [Command][build.bazel.remote.execution.v2.Command] to run, and the
    [Action][build.bazel.remote.execution.v2.Action] into the
    [ContentAddressableStorage][build.bazel.remote.execution.v2.ContentAddressableStorage].
    It then calls `Execute` with an `action_digest` referring to them. The
    server will run the action and eventually return the result.

    The input `Action`'s fields MUST meet the various canonicalization
    requirements specified in the documentation for their types so that it has
    the same digest as other logically equivalent `Action`s. The server MAY
    enforce the requirements and return errors if a non-canonical input is
    received. It MAY also proceed without verifying some or all of the
    requirements, such as for performance reasons. If the server does not
    verify the requirement, then it will treat the `Action` as distinct from
    another logically equivalent action if they hash differently.

    Returns a stream of
    [google.longrunning.Operation][google.longrunning.Operation] messages
    describing the resulting execution, with eventual `response`
    [ExecuteResponse][build.bazel.remote.execution.v2.ExecuteResponse]. The
    `metadata` on the operation is of type
    [ExecuteOperationMetadata][build.bazel.remote.execution.v2.ExecuteOperationMetadata].

    If the client remains connected after the first response is returned after
    the server, then updates are streamed as if the client had called
    [WaitExecution][build.bazel.remote.execution.v2.Execution.WaitExecution]
    until the execution completes or the request reaches an error. The
    operation can also be queried using [Operations
    API][google.longrunning.Operations.GetOperation].

    The server NEED NOT implement other methods or functionality of the
    Operations API.

    Errors discovered during creation of the `Operation` will be reported
    as gRPC Status errors, while errors that occurred while running the
    action will be reported in the `status` field of the `ExecuteResponse`. The
    server MUST NOT set the `error` field of the `Operation` proto.
    The possible errors include:

    * `INVALID_ARGUMENT`: One or more arguments are invalid.
    * `FAILED_PRECONDITION`: One or more errors occurred in setting up the
      action requested, such as a missing input or command or no worker being
      available. The client may be able to fix the errors and retry.
    * `RESOURCE_EXHAUSTED`: There is insufficient quota of some resource to run
      the action.
    * `UNAVAILABLE`: Due to a transient condition, such as all workers being
      occupied (and the server does not support a queue), the action could not
      be started. The client should retry.
    * `INTERNAL`: An internal error occurred in the execution engine or the
      worker.
    * `DEADLINE_EXCEEDED`: The execution timed out.
    * `CANCELLED`: The operation was cancelled by the client. This status is
      only possible if the server implements the Operations API CancelOperation
      method, and it was called for the current execution.

    In the case of a missing input or command, the server SHOULD additionally
    send a [PreconditionFailure][google.rpc.PreconditionFailure] error detail
    where, for each requested blob not present in the CAS, there is a
    `Violation` with a `type` of `MISSING` and a `subject` of
    `"blobs/{hash}/{size}"` indicating the digest of the missing blob.

    The server does not need to guarantee that a call to this method leads to
    at most one execution of the action. The server MAY execute the action
    multiple times, potentially in parallel. These redundant executions MAY
    continue to run, even if the operation is completed.
    """
    WaitExecution: grpc.UnaryStreamMultiCallable[
        buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.WaitExecutionRequest,
        buildgrid.common.protos.google.longrunning.operations_pb2.Operation,
    ]
    """Wait for an execution operation to complete. When the client initially
    makes the request, the server immediately responds with the current status
    of the execution. The server will leave the request stream open until the
    operation completes, and then respond with the completed operation. The
    server MAY choose to stream additional updates as execution progresses,
    such as to provide an update as to the state of the execution.
    """

class ExecutionServicer(metaclass=abc.ABCMeta):
    """The Remote Execution API is used to execute an
    [Action][build.bazel.remote.execution.v2.Action] on the remote
    workers.

    As with other services in the Remote Execution API, any call may return an
    error with a [RetryInfo][google.rpc.RetryInfo] error detail providing
    information about when the client should retry the request; clients SHOULD
    respect the information provided.
    """

    @abc.abstractmethod
    async def Execute(
        self,
        request: buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.ExecuteRequest,
        context: grpc.ServicerContext[typing.Any, typing.Any],
    ) -> collections.abc.AsyncIterator[buildgrid.common.protos.google.longrunning.operations_pb2.Operation]:
        """Execute an action remotely.

        In order to execute an action, the client must first upload all of the
        inputs, the
        [Command][build.bazel.remote.execution.v2.Command] to run, and the
        [Action][build.bazel.remote.execution.v2.Action] into the
        [ContentAddressableStorage][build.bazel.remote.execution.v2.ContentAddressableStorage].
        It then calls `Execute` with an `action_digest` referring to them. The
        server will run the action and eventually return the result.

        The input `Action`'s fields MUST meet the various canonicalization
        requirements specified in the documentation for their types so that it has
        the same digest as other logically equivalent `Action`s. The server MAY
        enforce the requirements and return errors if a non-canonical input is
        received. It MAY also proceed without verifying some or all of the
        requirements, such as for performance reasons. If the server does not
        verify the requirement, then it will treat the `Action` as distinct from
        another logically equivalent action if they hash differently.

        Returns a stream of
        [google.longrunning.Operation][google.longrunning.Operation] messages
        describing the resulting execution, with eventual `response`
        [ExecuteResponse][build.bazel.remote.execution.v2.ExecuteResponse]. The
        `metadata` on the operation is of type
        [ExecuteOperationMetadata][build.bazel.remote.execution.v2.ExecuteOperationMetadata].

        If the client remains connected after the first response is returned after
        the server, then updates are streamed as if the client had called
        [WaitExecution][build.bazel.remote.execution.v2.Execution.WaitExecution]
        until the execution completes or the request reaches an error. The
        operation can also be queried using [Operations
        API][google.longrunning.Operations.GetOperation].

        The server NEED NOT implement other methods or functionality of the
        Operations API.

        Errors discovered during creation of the `Operation` will be reported
        as gRPC Status errors, while errors that occurred while running the
        action will be reported in the `status` field of the `ExecuteResponse`. The
        server MUST NOT set the `error` field of the `Operation` proto.
        The possible errors include:

        * `INVALID_ARGUMENT`: One or more arguments are invalid.
        * `FAILED_PRECONDITION`: One or more errors occurred in setting up the
          action requested, such as a missing input or command or no worker being
          available. The client may be able to fix the errors and retry.
        * `RESOURCE_EXHAUSTED`: There is insufficient quota of some resource to run
          the action.
        * `UNAVAILABLE`: Due to a transient condition, such as all workers being
          occupied (and the server does not support a queue), the action could not
          be started. The client should retry.
        * `INTERNAL`: An internal error occurred in the execution engine or the
          worker.
        * `DEADLINE_EXCEEDED`: The execution timed out.
        * `CANCELLED`: The operation was cancelled by the client. This status is
          only possible if the server implements the Operations API CancelOperation
          method, and it was called for the current execution.

        In the case of a missing input or command, the server SHOULD additionally
        send a [PreconditionFailure][google.rpc.PreconditionFailure] error detail
        where, for each requested blob not present in the CAS, there is a
        `Violation` with a `type` of `MISSING` and a `subject` of
        `"blobs/{hash}/{size}"` indicating the digest of the missing blob.

        The server does not need to guarantee that a call to this method leads to
        at most one execution of the action. The server MAY execute the action
        multiple times, potentially in parallel. These redundant executions MAY
        continue to run, even if the operation is completed.
        """
    @abc.abstractmethod
    async def WaitExecution(
        self,
        request: buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.WaitExecutionRequest,
        context: grpc.ServicerContext[typing.Any, typing.Any],
    ) -> collections.abc.AsyncIterator[buildgrid.common.protos.google.longrunning.operations_pb2.Operation]:
        """Wait for an execution operation to complete. When the client initially
        makes the request, the server immediately responds with the current status
        of the execution. The server will leave the request stream open until the
        operation completes, and then respond with the completed operation. The
        server MAY choose to stream additional updates as execution progresses,
        such as to provide an update as to the state of the execution.
        """

def add_ExecutionServicer_to_server(servicer: ExecutionServicer, server: grpc.Server) -> None: ...

class ActionCacheStub:
    """The action cache API is used to query whether a given action has already been
    performed and, if so, retrieve its result. Unlike the
    [ContentAddressableStorage][build.bazel.remote.execution.v2.ContentAddressableStorage],
    which addresses blobs by their own content, the action cache addresses the
    [ActionResult][build.bazel.remote.execution.v2.ActionResult] by a
    digest of the encoded [Action][build.bazel.remote.execution.v2.Action]
    which produced them.

    The lifetime of entries in the action cache is implementation-specific, but
    the server SHOULD assume that more recently used entries are more likely to
    be used again.

    As with other services in the Remote Execution API, any call may return an
    error with a [RetryInfo][google.rpc.RetryInfo] error detail providing
    information about when the client should retry the request; clients SHOULD
    respect the information provided.
    """

    def __init__(self, channel: grpc.Channel) -> None: ...
    GetActionResult: grpc.UnaryUnaryMultiCallable[
        buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.GetActionResultRequest,
        buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.ActionResult,
    ]
    """Retrieve a cached execution result.

    Implementations SHOULD ensure that any blobs referenced from the
    [ContentAddressableStorage][build.bazel.remote.execution.v2.ContentAddressableStorage]
    are available at the time of returning the
    [ActionResult][build.bazel.remote.execution.v2.ActionResult] and will be
    for some period of time afterwards. The lifetimes of the referenced blobs SHOULD be increased
    if necessary and applicable.

    Errors:

    * `NOT_FOUND`: The requested `ActionResult` is not in the cache.
    """
    UpdateActionResult: grpc.UnaryUnaryMultiCallable[
        buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.UpdateActionResultRequest,
        buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.ActionResult,
    ]
    """Upload a new execution result.

    In order to allow the server to perform access control based on the type of
    action, and to assist with client debugging, the client MUST first upload
    the [Action][build.bazel.remote.execution.v2.Execution] that produced the
    result, along with its
    [Command][build.bazel.remote.execution.v2.Command], into the
    `ContentAddressableStorage`.

    Server implementations MAY modify the
    `UpdateActionResultRequest.action_result` and return an equivalent value.

    Errors:

    * `INVALID_ARGUMENT`: One or more arguments are invalid.
    * `FAILED_PRECONDITION`: One or more errors occurred in updating the
      action result, such as a missing command or action.
    * `RESOURCE_EXHAUSTED`: There is insufficient storage space to add the
      entry to the cache.
    """

class ActionCacheServicer(metaclass=abc.ABCMeta):
    """The action cache API is used to query whether a given action has already been
    performed and, if so, retrieve its result. Unlike the
    [ContentAddressableStorage][build.bazel.remote.execution.v2.ContentAddressableStorage],
    which addresses blobs by their own content, the action cache addresses the
    [ActionResult][build.bazel.remote.execution.v2.ActionResult] by a
    digest of the encoded [Action][build.bazel.remote.execution.v2.Action]
    which produced them.

    The lifetime of entries in the action cache is implementation-specific, but
    the server SHOULD assume that more recently used entries are more likely to
    be used again.

    As with other services in the Remote Execution API, any call may return an
    error with a [RetryInfo][google.rpc.RetryInfo] error detail providing
    information about when the client should retry the request; clients SHOULD
    respect the information provided.
    """

    @abc.abstractmethod
    async def GetActionResult(
        self,
        request: buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.GetActionResultRequest,
        context: grpc.ServicerContext[typing.Any, typing.Any],
    ) -> buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.ActionResult:
        """Retrieve a cached execution result.

        Implementations SHOULD ensure that any blobs referenced from the
        [ContentAddressableStorage][build.bazel.remote.execution.v2.ContentAddressableStorage]
        are available at the time of returning the
        [ActionResult][build.bazel.remote.execution.v2.ActionResult] and will be
        for some period of time afterwards. The lifetimes of the referenced blobs SHOULD be increased
        if necessary and applicable.

        Errors:

        * `NOT_FOUND`: The requested `ActionResult` is not in the cache.
        """
    @abc.abstractmethod
    async def UpdateActionResult(
        self,
        request: buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.UpdateActionResultRequest,
        context: grpc.ServicerContext[typing.Any, typing.Any],
    ) -> buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.ActionResult:
        """Upload a new execution result.

        In order to allow the server to perform access control based on the type of
        action, and to assist with client debugging, the client MUST first upload
        the [Action][build.bazel.remote.execution.v2.Execution] that produced the
        result, along with its
        [Command][build.bazel.remote.execution.v2.Command], into the
        `ContentAddressableStorage`.

        Server implementations MAY modify the
        `UpdateActionResultRequest.action_result` and return an equivalent value.

        Errors:

        * `INVALID_ARGUMENT`: One or more arguments are invalid.
        * `FAILED_PRECONDITION`: One or more errors occurred in updating the
          action result, such as a missing command or action.
        * `RESOURCE_EXHAUSTED`: There is insufficient storage space to add the
          entry to the cache.
        """

def add_ActionCacheServicer_to_server(servicer: ActionCacheServicer, server: grpc.Server) -> None: ...

class ContentAddressableStorageStub:
    """The CAS (content-addressable storage) is used to store the inputs to and
    outputs from the execution service. Each piece of content is addressed by the
    digest of its binary data.

    Most of the binary data stored in the CAS is opaque to the execution engine,
    and is only used as a communication medium. In order to build an
    [Action][build.bazel.remote.execution.v2.Action],
    however, the client will need to also upload the
    [Command][build.bazel.remote.execution.v2.Command] and input root
    [Directory][build.bazel.remote.execution.v2.Directory] for the Action.
    The Command and Directory messages must be marshalled to wire format and then
    uploaded under the hash as with any other piece of content. In practice, the
    input root directory is likely to refer to other Directories in its
    hierarchy, which must also each be uploaded on their own.

    For small file uploads the client should group them together and call
    [BatchUpdateBlobs][build.bazel.remote.execution.v2.ContentAddressableStorage.BatchUpdateBlobs].
    For large uploads, the client must use the
    [Write method][google.bytestream.ByteStream.Write] of the ByteStream API. The
    `resource_name` is `{instance_name}/uploads/{uuid}/blobs/{hash}/{size}`,
    where `instance_name` is as described in the next paragraph, `uuid` is a
    version 4 UUID generated by the client, and `hash` and `size` are the
    [Digest][build.bazel.remote.execution.v2.Digest] of the blob. The
    `uuid` is used only to avoid collisions when multiple clients try to upload
    the same file (or the same client tries to upload the file multiple times at
    once on different threads), so the client MAY reuse the `uuid` for uploading
    different blobs. The `resource_name` may optionally have a trailing filename
    (or other metadata) for a client to use if it is storing URLs, as in
    `{instance}/uploads/{uuid}/blobs/{hash}/{size}/foo/bar/baz.cc`. Anything
    after the `size` is ignored.

    A single server MAY support multiple instances of the execution system, each
    with their own workers, storage, cache, etc. The exact relationship between
    instances is up to the server. If the server does, then the `instance_name`
    is an identifier, possibly containing multiple path segments, used to
    distinguish between the various instances on the server, in a manner defined
    by the server. For servers which do not support multiple instances, then the
    `instance_name` is the empty path and the leading slash is omitted, so that
    the `resource_name` becomes `uploads/{uuid}/blobs/{hash}/{size}`.
    To simplify parsing, a path segment cannot equal any of the following
    keywords: `blobs`, `uploads`, `actions`, `actionResults`, `operations` and
    `capabilities`.

    When attempting an upload, if another client has already completed the upload
    (which may occur in the middle of a single upload if another client uploads
    the same blob concurrently), the request will terminate immediately with
    a response whose `committed_size` is the full size of the uploaded file
    (regardless of how much data was transmitted by the client). If the client
    completes the upload but the
    [Digest][build.bazel.remote.execution.v2.Digest] does not match, an
    `INVALID_ARGUMENT` error will be returned. In either case, the client should
    not attempt to retry the upload.

    For downloading blobs, the client must use the
    [Read method][google.bytestream.ByteStream.Read] of the ByteStream API, with
    a `resource_name` of `"{instance_name}/blobs/{hash}/{size}"`, where
    `instance_name` is the instance name (see above), and `hash` and `size` are
    the [Digest][build.bazel.remote.execution.v2.Digest] of the blob.

    The lifetime of entries in the CAS is implementation specific, but it SHOULD
    be long enough to allow for newly-added and recently looked-up entries to be
    used in subsequent calls (e.g. to
    [Execute][build.bazel.remote.execution.v2.Execution.Execute]).

    Servers MUST behave as though empty blobs are always available, even if they
    have not been uploaded. Clients MAY optimize away the uploading or
    downloading of empty blobs.

    As with other services in the Remote Execution API, any call may return an
    error with a [RetryInfo][google.rpc.RetryInfo] error detail providing
    information about when the client should retry the request; clients SHOULD
    respect the information provided.
    """

    def __init__(self, channel: grpc.Channel) -> None: ...
    FindMissingBlobs: grpc.UnaryUnaryMultiCallable[
        buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.FindMissingBlobsRequest,
        buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.FindMissingBlobsResponse,
    ]
    """Determine if blobs are present in the CAS.

    Clients can use this API before uploading blobs to determine which ones are
    already present in the CAS and do not need to be uploaded again.

    Servers SHOULD increase the lifetimes of the referenced blobs if necessary and
    applicable.

    There are no method-specific errors.
    """
    BatchUpdateBlobs: grpc.UnaryUnaryMultiCallable[
        buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.BatchUpdateBlobsRequest,
        buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.BatchUpdateBlobsResponse,
    ]
    """Upload many blobs at once.

    The server may enforce a limit of the combined total size of blobs
    to be uploaded using this API. This limit may be obtained using the
    [Capabilities][build.bazel.remote.execution.v2.Capabilities] API.
    Requests exceeding the limit should either be split into smaller
    chunks or uploaded using the
    [ByteStream API][google.bytestream.ByteStream], as appropriate.

    This request is equivalent to calling a Bytestream `Write` request
    on each individual blob, in parallel. The requests may succeed or fail
    independently.

    Errors:

    * `INVALID_ARGUMENT`: The client attempted to upload more than the
      server supported limit.

    Individual requests may return the following errors, additionally:

    * `RESOURCE_EXHAUSTED`: There is insufficient disk quota to store the blob.
    * `INVALID_ARGUMENT`: The
    [Digest][build.bazel.remote.execution.v2.Digest] does not match the
    provided data.
    """
    BatchReadBlobs: grpc.UnaryUnaryMultiCallable[
        buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.BatchReadBlobsRequest,
        buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.BatchReadBlobsResponse,
    ]
    """Download many blobs at once.

    The server may enforce a limit of the combined total size of blobs
    to be downloaded using this API. This limit may be obtained using the
    [Capabilities][build.bazel.remote.execution.v2.Capabilities] API.
    Requests exceeding the limit should either be split into smaller
    chunks or downloaded using the
    [ByteStream API][google.bytestream.ByteStream], as appropriate.

    This request is equivalent to calling a Bytestream `Read` request
    on each individual blob, in parallel. The requests may succeed or fail
    independently.

    Errors:

    * `INVALID_ARGUMENT`: The client attempted to read more than the
      server supported limit.

    Every error on individual read will be returned in the corresponding digest
    status.
    """
    GetTree: grpc.UnaryStreamMultiCallable[
        buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.GetTreeRequest,
        buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.GetTreeResponse,
    ]
    """Fetch the entire directory tree rooted at a node.

    This request must be targeted at a
    [Directory][build.bazel.remote.execution.v2.Directory] stored in the
    [ContentAddressableStorage][build.bazel.remote.execution.v2.ContentAddressableStorage]
    (CAS). The server will enumerate the `Directory` tree recursively and
    return every node descended from the root.

    The GetTreeRequest.page_token parameter can be used to skip ahead in
    the stream (e.g. when retrying a partially completed and aborted request),
    by setting it to a value taken from GetTreeResponse.next_page_token of the
    last successfully processed GetTreeResponse).

    The exact traversal order is unspecified and, unless retrieving subsequent
    pages from an earlier request, is not guaranteed to be stable across
    multiple invocations of `GetTree`.

    If part of the tree is missing from the CAS, the server will return the
    portion present and omit the rest.

    Errors:

    * `NOT_FOUND`: The requested tree root is not present in the CAS.
    """

class ContentAddressableStorageServicer(metaclass=abc.ABCMeta):
    """The CAS (content-addressable storage) is used to store the inputs to and
    outputs from the execution service. Each piece of content is addressed by the
    digest of its binary data.

    Most of the binary data stored in the CAS is opaque to the execution engine,
    and is only used as a communication medium. In order to build an
    [Action][build.bazel.remote.execution.v2.Action],
    however, the client will need to also upload the
    [Command][build.bazel.remote.execution.v2.Command] and input root
    [Directory][build.bazel.remote.execution.v2.Directory] for the Action.
    The Command and Directory messages must be marshalled to wire format and then
    uploaded under the hash as with any other piece of content. In practice, the
    input root directory is likely to refer to other Directories in its
    hierarchy, which must also each be uploaded on their own.

    For small file uploads the client should group them together and call
    [BatchUpdateBlobs][build.bazel.remote.execution.v2.ContentAddressableStorage.BatchUpdateBlobs].
    For large uploads, the client must use the
    [Write method][google.bytestream.ByteStream.Write] of the ByteStream API. The
    `resource_name` is `{instance_name}/uploads/{uuid}/blobs/{hash}/{size}`,
    where `instance_name` is as described in the next paragraph, `uuid` is a
    version 4 UUID generated by the client, and `hash` and `size` are the
    [Digest][build.bazel.remote.execution.v2.Digest] of the blob. The
    `uuid` is used only to avoid collisions when multiple clients try to upload
    the same file (or the same client tries to upload the file multiple times at
    once on different threads), so the client MAY reuse the `uuid` for uploading
    different blobs. The `resource_name` may optionally have a trailing filename
    (or other metadata) for a client to use if it is storing URLs, as in
    `{instance}/uploads/{uuid}/blobs/{hash}/{size}/foo/bar/baz.cc`. Anything
    after the `size` is ignored.

    A single server MAY support multiple instances of the execution system, each
    with their own workers, storage, cache, etc. The exact relationship between
    instances is up to the server. If the server does, then the `instance_name`
    is an identifier, possibly containing multiple path segments, used to
    distinguish between the various instances on the server, in a manner defined
    by the server. For servers which do not support multiple instances, then the
    `instance_name` is the empty path and the leading slash is omitted, so that
    the `resource_name` becomes `uploads/{uuid}/blobs/{hash}/{size}`.
    To simplify parsing, a path segment cannot equal any of the following
    keywords: `blobs`, `uploads`, `actions`, `actionResults`, `operations` and
    `capabilities`.

    When attempting an upload, if another client has already completed the upload
    (which may occur in the middle of a single upload if another client uploads
    the same blob concurrently), the request will terminate immediately with
    a response whose `committed_size` is the full size of the uploaded file
    (regardless of how much data was transmitted by the client). If the client
    completes the upload but the
    [Digest][build.bazel.remote.execution.v2.Digest] does not match, an
    `INVALID_ARGUMENT` error will be returned. In either case, the client should
    not attempt to retry the upload.

    For downloading blobs, the client must use the
    [Read method][google.bytestream.ByteStream.Read] of the ByteStream API, with
    a `resource_name` of `"{instance_name}/blobs/{hash}/{size}"`, where
    `instance_name` is the instance name (see above), and `hash` and `size` are
    the [Digest][build.bazel.remote.execution.v2.Digest] of the blob.

    The lifetime of entries in the CAS is implementation specific, but it SHOULD
    be long enough to allow for newly-added and recently looked-up entries to be
    used in subsequent calls (e.g. to
    [Execute][build.bazel.remote.execution.v2.Execution.Execute]).

    Servers MUST behave as though empty blobs are always available, even if they
    have not been uploaded. Clients MAY optimize away the uploading or
    downloading of empty blobs.

    As with other services in the Remote Execution API, any call may return an
    error with a [RetryInfo][google.rpc.RetryInfo] error detail providing
    information about when the client should retry the request; clients SHOULD
    respect the information provided.
    """

    @abc.abstractmethod
    async def FindMissingBlobs(
        self,
        request: buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.FindMissingBlobsRequest,
        context: grpc.ServicerContext[typing.Any, typing.Any],
    ) -> buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.FindMissingBlobsResponse:
        """Determine if blobs are present in the CAS.

        Clients can use this API before uploading blobs to determine which ones are
        already present in the CAS and do not need to be uploaded again.

        Servers SHOULD increase the lifetimes of the referenced blobs if necessary and
        applicable.

        There are no method-specific errors.
        """
    @abc.abstractmethod
    async def BatchUpdateBlobs(
        self,
        request: buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.BatchUpdateBlobsRequest,
        context: grpc.ServicerContext[typing.Any, typing.Any],
    ) -> buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.BatchUpdateBlobsResponse:
        """Upload many blobs at once.

        The server may enforce a limit of the combined total size of blobs
        to be uploaded using this API. This limit may be obtained using the
        [Capabilities][build.bazel.remote.execution.v2.Capabilities] API.
        Requests exceeding the limit should either be split into smaller
        chunks or uploaded using the
        [ByteStream API][google.bytestream.ByteStream], as appropriate.

        This request is equivalent to calling a Bytestream `Write` request
        on each individual blob, in parallel. The requests may succeed or fail
        independently.

        Errors:

        * `INVALID_ARGUMENT`: The client attempted to upload more than the
          server supported limit.

        Individual requests may return the following errors, additionally:

        * `RESOURCE_EXHAUSTED`: There is insufficient disk quota to store the blob.
        * `INVALID_ARGUMENT`: The
        [Digest][build.bazel.remote.execution.v2.Digest] does not match the
        provided data.
        """
    @abc.abstractmethod
    async def BatchReadBlobs(
        self,
        request: buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.BatchReadBlobsRequest,
        context: grpc.ServicerContext[typing.Any, typing.Any],
    ) -> buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.BatchReadBlobsResponse:
        """Download many blobs at once.

        The server may enforce a limit of the combined total size of blobs
        to be downloaded using this API. This limit may be obtained using the
        [Capabilities][build.bazel.remote.execution.v2.Capabilities] API.
        Requests exceeding the limit should either be split into smaller
        chunks or downloaded using the
        [ByteStream API][google.bytestream.ByteStream], as appropriate.

        This request is equivalent to calling a Bytestream `Read` request
        on each individual blob, in parallel. The requests may succeed or fail
        independently.

        Errors:

        * `INVALID_ARGUMENT`: The client attempted to read more than the
          server supported limit.

        Every error on individual read will be returned in the corresponding digest
        status.
        """
    @abc.abstractmethod
    async def GetTree(
        self,
        request: buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.GetTreeRequest,
        context: grpc.ServicerContext[typing.Any, typing.Any],
    ) -> collections.abc.AsyncIterator[buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.GetTreeResponse]:
        """Fetch the entire directory tree rooted at a node.

        This request must be targeted at a
        [Directory][build.bazel.remote.execution.v2.Directory] stored in the
        [ContentAddressableStorage][build.bazel.remote.execution.v2.ContentAddressableStorage]
        (CAS). The server will enumerate the `Directory` tree recursively and
        return every node descended from the root.

        The GetTreeRequest.page_token parameter can be used to skip ahead in
        the stream (e.g. when retrying a partially completed and aborted request),
        by setting it to a value taken from GetTreeResponse.next_page_token of the
        last successfully processed GetTreeResponse).

        The exact traversal order is unspecified and, unless retrieving subsequent
        pages from an earlier request, is not guaranteed to be stable across
        multiple invocations of `GetTree`.

        If part of the tree is missing from the CAS, the server will return the
        portion present and omit the rest.

        Errors:

        * `NOT_FOUND`: The requested tree root is not present in the CAS.
        """

def add_ContentAddressableStorageServicer_to_server(servicer: ContentAddressableStorageServicer, server: grpc.Server) -> None: ...

class CapabilitiesStub:
    """The Capabilities service may be used by remote execution clients to query
    various server properties, in order to self-configure or return meaningful
    error messages.

    The query may include a particular `instance_name`, in which case the values
    returned will pertain to that instance.
    """

    def __init__(self, channel: grpc.Channel) -> None: ...
    GetCapabilities: grpc.UnaryUnaryMultiCallable[
        buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.GetCapabilitiesRequest,
        buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.ServerCapabilities,
    ]
    """GetCapabilities returns the server capabilities configuration of the
    remote endpoint.
    Only the capabilities of the services supported by the endpoint will
    be returned:
    * Execution + CAS + Action Cache endpoints should return both
      CacheCapabilities and ExecutionCapabilities.
    * Execution only endpoints should return ExecutionCapabilities.
    * CAS + Action Cache only endpoints should return CacheCapabilities.
    """

class CapabilitiesServicer(metaclass=abc.ABCMeta):
    """The Capabilities service may be used by remote execution clients to query
    various server properties, in order to self-configure or return meaningful
    error messages.

    The query may include a particular `instance_name`, in which case the values
    returned will pertain to that instance.
    """

    @abc.abstractmethod
    async def GetCapabilities(
        self,
        request: buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.GetCapabilitiesRequest,
        context: grpc.ServicerContext[typing.Any, typing.Any],
    ) -> buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.ServerCapabilities:
        """GetCapabilities returns the server capabilities configuration of the
        remote endpoint.
        Only the capabilities of the services supported by the endpoint will
        be returned:
        * Execution + CAS + Action Cache endpoints should return both
          CacheCapabilities and ExecutionCapabilities.
        * Execution only endpoints should return ExecutionCapabilities.
        * CAS + Action Cache only endpoints should return CacheCapabilities.
        """

def add_CapabilitiesServicer_to_server(servicer: CapabilitiesServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright (C) 2021 Bloomberg LP

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

 <http://www.apache.org/licenses/LICENSE-2.0>

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
import buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2
import builtins
import collections.abc
import buildgrid.common.protos.google.longrunning.operations_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Job(google.protobuf.message.Message):
    """Describes an individual execution of a specific Action. Serialized
    and published on the Execution exchange.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_ID_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    job_id: builtins.str
    """The unique ID of this specific execution of the Action. This MUST be
    unique within the grid at any given time, since it identifies a
    deliberately separate execution of an Action.
    """
    @property
    def action(self) -> buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.Action:
        """The Action to execute for this Job. The same Action can be used in
        multiple Jobs, for example an uncacheable Action being run multiple
        times simultaneously.
        """
    def __init__(
        self,
        *,
        job_id: builtins.str = ...,
        action: buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.Action | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["action", b"action"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "job_id", b"job_id"]) -> None: ...

global___Job = Job

@typing_extensions.final
class CreateOperation(google.protobuf.message.Message):
    """Message to indicate that a new Operation is being created for a Job."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_ID_FIELD_NUMBER: builtins.int
    OPERATION_NAME_FIELD_NUMBER: builtins.int
    ACTION_DIGEST_FIELD_NUMBER: builtins.int
    CACHEABLE_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    REQUEST_METADATA_FIELD_NUMBER: builtins.int
    job_id: builtins.str
    """Job ID that the Operation refers to. If this is an ID which has been
    used before then Operations services MUST treat this message as a
    request to bind the Operation name to the existing Job.
    """
    operation_name: builtins.str
    """The name of the Operation being created. This MUST be unique within
    the grid at any given time, since it identifies a specific client with
    an interest in the execution of a Job.
    """
    @property
    def action_digest(self) -> buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.Digest:
        """The Digest of the Action used in the Job. Services MUST use this
        digest when constructing Operation messages with the given name for
        response to clients.
        """
    cacheable: builtins.bool
    """Whether or not the result of the Action specified by the action_digest
    can be stored in the ActionCache. Execution services SHOULD use this
    to efficiently maintain a cache of Jobs which can have future requests
    deduplicated into them.
    """
    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The time at which this message was generated. Operations services
        SHOULD use this information to ensure in-order updating of persistent
        Operation state.
        """
    @property
    def request_metadata(self) -> buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.RequestMetadata:
        """Optional metadata that a client could have attached to the
        execution request. It serves to describe an external context of
        that request.
        """
    def __init__(
        self,
        *,
        job_id: builtins.str = ...,
        operation_name: builtins.str = ...,
        action_digest: buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.Digest | None = ...,
        cacheable: builtins.bool = ...,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        request_metadata: buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.RequestMetadata | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["action_digest", b"action_digest", "request_metadata", b"request_metadata", "timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action_digest", b"action_digest", "cacheable", b"cacheable", "job_id", b"job_id", "operation_name", b"operation_name", "request_metadata", b"request_metadata", "timestamp", b"timestamp"]) -> None: ...

global___CreateOperation = CreateOperation

@typing_extensions.final
class UpdateOperations(google.protobuf.message.Message):
    """Message containing an update to Operations related to a specific Job."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_ID_FIELD_NUMBER: builtins.int
    OPERATION_STATE_FIELD_NUMBER: builtins.int
    CACHEABLE_FIELD_NUMBER: builtins.int
    TIMESTAMP_FIELD_NUMBER: builtins.int
    job_id: builtins.str
    """The ID of the Job whose Operations should be updated to match the new
    state.
    """
    @property
    def operation_state(self) -> buildgrid.common.protos.google.longrunning.operations_pb2.Operation:
        """The new state of Operations for the Job. The `operation_state.name` is
        expected to be empty and will be ignored if set.
        """
    cacheable: builtins.bool
    """Whether or not the result of the Action specified by the action_digest
    in the operation_state can be stored in the ActionCache. Execution
    services SHOULD use this to efficiently maintain a cache of Jobs which
    can have future requests deduplicated into them, and ActionCache
    services SHOULD use this to determine whether or not the result stored
    in operation_state can be added to the cache in situations where the
    Job has been completed.
    """
    @property
    def timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The time at which this message was generated. Operation services
        SHOULD use this information to ensure in-order updating of persistent
        Operation state.
        """
    def __init__(
        self,
        *,
        job_id: builtins.str = ...,
        operation_state: buildgrid.common.protos.google.longrunning.operations_pb2.Operation | None = ...,
        cacheable: builtins.bool = ...,
        timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["operation_state", b"operation_state", "timestamp", b"timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cacheable", b"cacheable", "job_id", b"job_id", "operation_state", b"operation_state", "timestamp", b"timestamp"]) -> None: ...

global___UpdateOperations = UpdateOperations

@typing_extensions.final
class RetryableJob(google.protobuf.message.Message):
    """A message containing the information required to retry a Job which is
    currently being executed by a worker.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOB_ID_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    ROUTING_KEY_FIELD_NUMBER: builtins.int
    job_id: builtins.str
    """The unique ID of the Job that the worker is executing."""
    @property
    def action(self) -> buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.Action:
        """The Action to execute for this Job."""
    routing_key: builtins.str
    """The routing key used when this Job was originally published on the
    Execution exchange. This can be used to requeue the Job in the
    correct platform queue.
    """
    def __init__(
        self,
        *,
        job_id: builtins.str = ...,
        action: buildgrid.common.protos.build.bazel.remote.execution.v2.remote_execution_pb2.Action | None = ...,
        routing_key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["action", b"action"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "job_id", b"job_id", "routing_key", b"routing_key"]) -> None: ...

global___RetryableJob = RetryableJob

@typing_extensions.final
class BotStatus(google.protobuf.message.Message):
    """A message describing the last-known state of a bot."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BOT_NAME_FIELD_NUMBER: builtins.int
    ASSIGNMENTS_FIELD_NUMBER: builtins.int
    CONNECTION_TIMESTAMP_FIELD_NUMBER: builtins.int
    bot_name: builtins.str
    """The server-assigned name for this bot."""
    @property
    def assignments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RetryableJob]:
        """A list of RetryableJobs that this bot is currently working on, and would
        need to be retried or cancelled in the case of this bot failing to report
        back to the grid.
        """
    @property
    def connection_timestamp(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The timestamp of the last time the bot was seen connecting to the grid.
        The BotMonitor service SHOULD use this timestamp to determine that a
        bot has failed to meet its next connection deadline to trigger retrying
        the related Jobs.
        """
    def __init__(
        self,
        *,
        bot_name: builtins.str = ...,
        assignments: collections.abc.Iterable[global___RetryableJob] | None = ...,
        connection_timestamp: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connection_timestamp", b"connection_timestamp"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["assignments", b"assignments", "bot_name", b"bot_name", "connection_timestamp", b"connection_timestamp"]) -> None: ...

global___BotStatus = BotStatus



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from buildgrid.common.protos.buildstream.v2 import buildstream_pb2 as buildstream_dot_v2_dot_buildstream__pb2


class ReferenceStorageStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetReference = channel.unary_unary(
                '/buildstream.v2.ReferenceStorage/GetReference',
                request_serializer=buildstream_dot_v2_dot_buildstream__pb2.GetReferenceRequest.SerializeToString,
                response_deserializer=buildstream_dot_v2_dot_buildstream__pb2.GetReferenceResponse.FromString,
                )
        self.UpdateReference = channel.unary_unary(
                '/buildstream.v2.ReferenceStorage/UpdateReference',
                request_serializer=buildstream_dot_v2_dot_buildstream__pb2.UpdateReferenceRequest.SerializeToString,
                response_deserializer=buildstream_dot_v2_dot_buildstream__pb2.UpdateReferenceResponse.FromString,
                )
        self.Status = channel.unary_unary(
                '/buildstream.v2.ReferenceStorage/Status',
                request_serializer=buildstream_dot_v2_dot_buildstream__pb2.StatusRequest.SerializeToString,
                response_deserializer=buildstream_dot_v2_dot_buildstream__pb2.StatusResponse.FromString,
                )


class ReferenceStorageServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetReference(self, request, context):
        """Retrieve a CAS [Directory][build.bazel.remote.execution.v2.Directory]
        digest by name.

        Errors:
        * `NOT_FOUND`: The requested reference is not in the cache.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateReference(self, request, context):
        """Associate a name with a CAS [Directory][build.bazel.remote.execution.v2.Directory]
        digest.

        Errors:
        * `RESOURCE_EXHAUSTED`: There is insufficient storage space to add the
        entry to the cache.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Status(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ReferenceStorageServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetReference': grpc.unary_unary_rpc_method_handler(
                    servicer.GetReference,
                    request_deserializer=buildstream_dot_v2_dot_buildstream__pb2.GetReferenceRequest.FromString,
                    response_serializer=buildstream_dot_v2_dot_buildstream__pb2.GetReferenceResponse.SerializeToString,
            ),
            'UpdateReference': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateReference,
                    request_deserializer=buildstream_dot_v2_dot_buildstream__pb2.UpdateReferenceRequest.FromString,
                    response_serializer=buildstream_dot_v2_dot_buildstream__pb2.UpdateReferenceResponse.SerializeToString,
            ),
            'Status': grpc.unary_unary_rpc_method_handler(
                    servicer.Status,
                    request_deserializer=buildstream_dot_v2_dot_buildstream__pb2.StatusRequest.FromString,
                    response_serializer=buildstream_dot_v2_dot_buildstream__pb2.StatusResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'buildstream.v2.ReferenceStorage', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ReferenceStorage(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetReference(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/buildstream.v2.ReferenceStorage/GetReference',
            buildstream_dot_v2_dot_buildstream__pb2.GetReferenceRequest.SerializeToString,
            buildstream_dot_v2_dot_buildstream__pb2.GetReferenceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateReference(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/buildstream.v2.ReferenceStorage/UpdateReference',
            buildstream_dot_v2_dot_buildstream__pb2.UpdateReferenceRequest.SerializeToString,
            buildstream_dot_v2_dot_buildstream__pb2.UpdateReferenceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Status(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/buildstream.v2.ReferenceStorage/Status',
            buildstream_dot_v2_dot_buildstream__pb2.StatusRequest.SerializeToString,
            buildstream_dot_v2_dot_buildstream__pb2.StatusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from buildgrid.common.protos.google.devtools.remoteworkers.v1test2 import bots_pb2 as google_dot_devtools_dot_remoteworkers_dot_v1test2_dot_bots__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class BotsStub(object):
    """Design doc: https://goo.gl/oojM5H

    Loosely speaking, the Bots interface monitors a collection of workers (think
    of them as "computers" for a moment). This collection is known as a "farm,"
    and its purpose is to perform work on behalf of a client.

    Each worker runs a small program known as a "bot" that allows it to be
    controlled by the server. This interface contains only methods that are
    called by the bots themselves; admin functionality is out of scope for this
    interface.

    More precisely, we use the term "worker" to refer to the physical "thing"
    running the bot. We use the term "worker," and not "machine" or "computer,"
    since a worker may consist of more than one machine - e.g., a computer with
    multiple attached devices, or even a cluster of computers, with only one of
    them running the bot. Conversely, a single machine may host several bots, in
    which case each bot has a "worker" corresponding to the slice of the machine
    being managed by that bot.

    The main resource in the Bots interface is not, surprisingly, a Bot - it is a
    BotSession, which represents a period of time in which a bot is in continuous
    contact with the server (see the BotSession message for more information).
    The parent of a bot session can be thought of as an instance of a farm. That
    is, one endpoint may be able to manage many farms for many users. For
    example, for a farm managed through GCP, the parent resource will typically
    take the form "projects/{project_id}". This is referred to below as "the farm
    resource."
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateBotSession = channel.unary_unary(
                '/google.devtools.remoteworkers.v1test2.Bots/CreateBotSession',
                request_serializer=google_dot_devtools_dot_remoteworkers_dot_v1test2_dot_bots__pb2.CreateBotSessionRequest.SerializeToString,
                response_deserializer=google_dot_devtools_dot_remoteworkers_dot_v1test2_dot_bots__pb2.BotSession.FromString,
                )
        self.UpdateBotSession = channel.unary_unary(
                '/google.devtools.remoteworkers.v1test2.Bots/UpdateBotSession',
                request_serializer=google_dot_devtools_dot_remoteworkers_dot_v1test2_dot_bots__pb2.UpdateBotSessionRequest.SerializeToString,
                response_deserializer=google_dot_devtools_dot_remoteworkers_dot_v1test2_dot_bots__pb2.BotSession.FromString,
                )
        self.PostBotEventTemp = channel.unary_unary(
                '/google.devtools.remoteworkers.v1test2.Bots/PostBotEventTemp',
                request_serializer=google_dot_devtools_dot_remoteworkers_dot_v1test2_dot_bots__pb2.PostBotEventTempRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class BotsServicer(object):
    """Design doc: https://goo.gl/oojM5H

    Loosely speaking, the Bots interface monitors a collection of workers (think
    of them as "computers" for a moment). This collection is known as a "farm,"
    and its purpose is to perform work on behalf of a client.

    Each worker runs a small program known as a "bot" that allows it to be
    controlled by the server. This interface contains only methods that are
    called by the bots themselves; admin functionality is out of scope for this
    interface.

    More precisely, we use the term "worker" to refer to the physical "thing"
    running the bot. We use the term "worker," and not "machine" or "computer,"
    since a worker may consist of more than one machine - e.g., a computer with
    multiple attached devices, or even a cluster of computers, with only one of
    them running the bot. Conversely, a single machine may host several bots, in
    which case each bot has a "worker" corresponding to the slice of the machine
    being managed by that bot.

    The main resource in the Bots interface is not, surprisingly, a Bot - it is a
    BotSession, which represents a period of time in which a bot is in continuous
    contact with the server (see the BotSession message for more information).
    The parent of a bot session can be thought of as an instance of a farm. That
    is, one endpoint may be able to manage many farms for many users. For
    example, for a farm managed through GCP, the parent resource will typically
    take the form "projects/{project_id}". This is referred to below as "the farm
    resource."
    """

    def CreateBotSession(self, request, context):
        """CreateBotSession is called when the bot first joins the farm, and
        establishes a session ID to ensure that multiple machines do not register
        using the same name accidentally.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateBotSession(self, request, context):
        """UpdateBotSession must be called periodically by the bot (on a schedule
        determined by the server) to let the server know about its status, and to
        pick up new lease requests from the server.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PostBotEventTemp(self, request, context):
        """PostBotEventTemp may be called by the bot to indicate that some exceptional
        event has occurred. This method is subject to change or removal in future
        revisions of this API; we may simply want to replace it with StackDriver or
        some other common interface.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_BotsServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateBotSession': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateBotSession,
                    request_deserializer=google_dot_devtools_dot_remoteworkers_dot_v1test2_dot_bots__pb2.CreateBotSessionRequest.FromString,
                    response_serializer=google_dot_devtools_dot_remoteworkers_dot_v1test2_dot_bots__pb2.BotSession.SerializeToString,
            ),
            'UpdateBotSession': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateBotSession,
                    request_deserializer=google_dot_devtools_dot_remoteworkers_dot_v1test2_dot_bots__pb2.UpdateBotSessionRequest.FromString,
                    response_serializer=google_dot_devtools_dot_remoteworkers_dot_v1test2_dot_bots__pb2.BotSession.SerializeToString,
            ),
            'PostBotEventTemp': grpc.unary_unary_rpc_method_handler(
                    servicer.PostBotEventTemp,
                    request_deserializer=google_dot_devtools_dot_remoteworkers_dot_v1test2_dot_bots__pb2.PostBotEventTempRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'google.devtools.remoteworkers.v1test2.Bots', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Bots(object):
    """Design doc: https://goo.gl/oojM5H

    Loosely speaking, the Bots interface monitors a collection of workers (think
    of them as "computers" for a moment). This collection is known as a "farm,"
    and its purpose is to perform work on behalf of a client.

    Each worker runs a small program known as a "bot" that allows it to be
    controlled by the server. This interface contains only methods that are
    called by the bots themselves; admin functionality is out of scope for this
    interface.

    More precisely, we use the term "worker" to refer to the physical "thing"
    running the bot. We use the term "worker," and not "machine" or "computer,"
    since a worker may consist of more than one machine - e.g., a computer with
    multiple attached devices, or even a cluster of computers, with only one of
    them running the bot. Conversely, a single machine may host several bots, in
    which case each bot has a "worker" corresponding to the slice of the machine
    being managed by that bot.

    The main resource in the Bots interface is not, surprisingly, a Bot - it is a
    BotSession, which represents a period of time in which a bot is in continuous
    contact with the server (see the BotSession message for more information).
    The parent of a bot session can be thought of as an instance of a farm. That
    is, one endpoint may be able to manage many farms for many users. For
    example, for a farm managed through GCP, the parent resource will typically
    take the form "projects/{project_id}". This is referred to below as "the farm
    resource."
    """

    @staticmethod
    def CreateBotSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/google.devtools.remoteworkers.v1test2.Bots/CreateBotSession',
            google_dot_devtools_dot_remoteworkers_dot_v1test2_dot_bots__pb2.CreateBotSessionRequest.SerializeToString,
            google_dot_devtools_dot_remoteworkers_dot_v1test2_dot_bots__pb2.BotSession.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateBotSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/google.devtools.remoteworkers.v1test2.Bots/UpdateBotSession',
            google_dot_devtools_dot_remoteworkers_dot_v1test2_dot_bots__pb2.UpdateBotSessionRequest.SerializeToString,
            google_dot_devtools_dot_remoteworkers_dot_v1test2_dot_bots__pb2.BotSession.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PostBotEventTemp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/google.devtools.remoteworkers.v1test2.Bots/PostBotEventTemp',
            google_dot_devtools_dot_remoteworkers_dot_v1test2_dot_bots__pb2.PostBotEventTempRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/devtools/build/v1/build_status.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+google/devtools/build/v1/build_status.proto\x12\x18google.devtools.build.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x19google/protobuf/any.proto\"\x9e\x03\n\x0b\x42uildStatus\x12<\n\x06result\x18\x01 \x01(\x0e\x32,.google.devtools.build.v1.BuildStatus.Result\x12\x1b\n\x13\x66inal_invocation_id\x18\x03 \x01(\t\x12\x39\n\x14\x62uild_tool_exit_code\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12%\n\x07\x64\x65tails\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\"\xd1\x01\n\x06Result\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\x15\n\x11\x43OMMAND_SUCCEEDED\x10\x01\x12\x12\n\x0e\x43OMMAND_FAILED\x10\x02\x12\x0e\n\nUSER_ERROR\x10\x03\x12\x10\n\x0cSYSTEM_ERROR\x10\x04\x12\x16\n\x12RESOURCE_EXHAUSTED\x10\x05\x12 \n\x1cINVOCATION_DEADLINE_EXCEEDED\x10\x06\x12\x1d\n\x19REQUEST_DEADLINE_EXCEEDED\x10\x08\x12\r\n\tCANCELLED\x10\x07\x42\x8c\x01\n\x1c\x63om.google.devtools.build.v1B\x10\x42uildStatusProtoP\x01Z=google.golang.org/genproto/googleapis/devtools/build/v1;build\xf8\x01\x01\xca\x02\x15Google\\Cloud\\Build\\V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'buildgrid.common.protos.google.devtools.build.v1.build_status_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034com.google.devtools.build.v1B\020BuildStatusProtoP\001Z=google.golang.org/genproto/googleapis/devtools/build/v1;build\370\001\001\312\002\025Google\\Cloud\\Build\\V1'
  _globals['_BUILDSTATUS']._serialized_start=133
  _globals['_BUILDSTATUS']._serialized_end=547
  _globals['_BUILDSTATUS_RESULT']._serialized_start=338
  _globals['_BUILDSTATUS_RESULT']._serialized_end=547
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2018 Google LLC

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
import builtins
import collections.abc
import buildgrid.common.protos.google.devtools.remoteworkers.v1test2.worker_pb2
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import buildgrid.common.protos.google.rpc.status_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _BotStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _BotStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_BotStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    BOT_STATUS_UNSPECIFIED: _BotStatus.ValueType  # 0
    """Default value; do not use."""
    OK: _BotStatus.ValueType  # 1
    """The bot is healthy, and will accept leases as normal."""
    UNHEALTHY: _BotStatus.ValueType  # 2
    """The bot is unhealthy and will not accept new leases. For example, the bot
    may have detected that available disk space is too low. This situation may
    resolve itself, but will typically require human intervention.
    """
    HOST_REBOOTING: _BotStatus.ValueType  # 3
    """The bot has been asked to reboot the host. The bot will not accept new
    leases; once all leases are complete, this session will no longer be
    updated but the bot will be expected to establish a new session after the
    reboot completes.
    """
    BOT_TERMINATING: _BotStatus.ValueType  # 4
    """The bot has been asked to shut down. As with HOST_REBOOTING, once all
    leases are completed, the session will no longer be updated and the bot
    will not be expected to establish a new session.

    Bots are typically only asked to shut down if its host computer will be
    modified in some way, such as deleting a VM.
    """

class BotStatus(_BotStatus, metaclass=_BotStatusEnumTypeWrapper):
    """A coarse description of the status of the bot that the server uses to
    determine whether to assign the bot new leases.
    """

BOT_STATUS_UNSPECIFIED: BotStatus.ValueType  # 0
"""Default value; do not use."""
OK: BotStatus.ValueType  # 1
"""The bot is healthy, and will accept leases as normal."""
UNHEALTHY: BotStatus.ValueType  # 2
"""The bot is unhealthy and will not accept new leases. For example, the bot
may have detected that available disk space is too low. This situation may
resolve itself, but will typically require human intervention.
"""
HOST_REBOOTING: BotStatus.ValueType  # 3
"""The bot has been asked to reboot the host. The bot will not accept new
leases; once all leases are complete, this session will no longer be
updated but the bot will be expected to establish a new session after the
reboot completes.
"""
BOT_TERMINATING: BotStatus.ValueType  # 4
"""The bot has been asked to shut down. As with HOST_REBOOTING, once all
leases are completed, the session will no longer be updated and the bot
will not be expected to establish a new session.

Bots are typically only asked to shut down if its host computer will be
modified in some way, such as deleting a VM.
"""
global___BotStatus = BotStatus

class _LeaseState:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _LeaseStateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_LeaseState.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    LEASE_STATE_UNSPECIFIED: _LeaseState.ValueType  # 0
    """Default value; do not use."""
    PENDING: _LeaseState.ValueType  # 1
    """Pending: the server expects the bot to accept this lease. This may only be
    set by the server.
    """
    ACTIVE: _LeaseState.ValueType  # 2
    """Active: the bot has accepted this lease. This may only be set by the bot."""
    COMPLETED: _LeaseState.ValueType  # 4
    """Completed: the bot is no longer leased. This may only be set by the bot,
    and the status field must be populated iff the state is COMPLETED.
    """
    CANCELLED: _LeaseState.ValueType  # 5
    """Cancelled: The bot should immediately release all resources associated with
    the lease. This may only be set by the server.
    """

class LeaseState(_LeaseState, metaclass=_LeaseStateEnumTypeWrapper):
    """The state of the lease. All leases start in the PENDING state. A bot can
    change PENDING to ACTIVE or (in the case of an error) COMPLETED, or from
    ACTIVE to COMPLETED. The server can change PENDING or ACTIVE to CANCELLED if
    it wants the bot to release its resources - for example, if the bot needs to
    be quarantined (it's producing bad output) or a cell needs to be drained.
    """

LEASE_STATE_UNSPECIFIED: LeaseState.ValueType  # 0
"""Default value; do not use."""
PENDING: LeaseState.ValueType  # 1
"""Pending: the server expects the bot to accept this lease. This may only be
set by the server.
"""
ACTIVE: LeaseState.ValueType  # 2
"""Active: the bot has accepted this lease. This may only be set by the bot."""
COMPLETED: LeaseState.ValueType  # 4
"""Completed: the bot is no longer leased. This may only be set by the bot,
and the status field must be populated iff the state is COMPLETED.
"""
CANCELLED: LeaseState.ValueType  # 5
"""Cancelled: The bot should immediately release all resources associated with
the lease. This may only be set by the server.
"""
global___LeaseState = LeaseState

@typing_extensions.final
class BotSession(google.protobuf.message.Message):
    """A bot session represents the state of a bot while in continuous contact with
    the server for a period of time. The session includes information about the
    worker - that is, the *worker* (the physical or virtual hardware) is
    considered to be a property of the bot (the software agent running on that
    hardware), which is the reverse of real life, but more natural from the point
    of the view of this API, which communicates solely with the bot and not
    directly with the underlying worker.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    BOT_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    WORKER_FIELD_NUMBER: builtins.int
    LEASES_FIELD_NUMBER: builtins.int
    EXPIRE_TIME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The bot session name, as selected by the server. Output only during a call
    to CreateBotSession.
    """
    bot_id: builtins.str
    """A unique bot ID within the farm used to persistently identify this bot over
    time (i.e., over multiple sessions). This ID must be unique within a
    farm. Typically, the bot ID will be the same as the name of the primary
    device in the worker (e.g., what you'd get from typing `uname -n` on *nix),
    but this is not required since a single device may allow multiple bots to
    run on it, each with access to different resources. What is important is
    that this ID is meaningful to humans, who might need to hunt a physical
    machine down to fix it.

    When CreateBotSession is successfully called with a bot_id, all prior
    sessions with the same ID are invalidated. If a bot attempts to update an
    invalid session, the server must reject that request, and may also
    quarantine the other bot with the same bot IDs (ie, stop sending it new
    leases and alert an admin).
    """
    status: global___BotStatus.ValueType
    """The status of the bot. This must be populated in every call to
    UpdateBotSession.
    """
    @property
    def worker(self) -> buildgrid.common.protos.google.devtools.remoteworkers.v1test2.worker_pb2.Worker:
        """A description of the worker hosting this bot. The Worker message is used
        here in the Status context (see Worker for more information).  If multiple
        bots are running on the worker, this field should only describe the
        resources accessible from this bot.

        During the call to CreateBotSession, the server may make arbitrary changes
        to the worker's `server_properties` field (see that field for more
        information). Otherwise, this field is input-only.
        """
    @property
    def leases(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Lease]:
        """A list of all leases that are a part of this session. See the Lease message
        for details.
        """
    @property
    def expire_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The time at which this bot session will expire, unless the bot calls
        UpdateBotSession again. Output only.
        """
    version: builtins.str
    """The version of the bot code currently running. The server may use this
    information to issue an admin action to tell the bot to update itself.
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        bot_id: builtins.str = ...,
        status: global___BotStatus.ValueType = ...,
        worker: buildgrid.common.protos.google.devtools.remoteworkers.v1test2.worker_pb2.Worker | None = ...,
        leases: collections.abc.Iterable[global___Lease] | None = ...,
        expire_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["expire_time", b"expire_time", "worker", b"worker"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bot_id", b"bot_id", "expire_time", b"expire_time", "leases", b"leases", "name", b"name", "status", b"status", "version", b"version", "worker", b"worker"]) -> None: ...

global___BotSession = BotSession

@typing_extensions.final
class Lease(google.protobuf.message.Message):
    """A Lease is a lease that the scheduler has assigned to this bot. If the bot
    notices (by UpdateBotSession) that it has any leases in the PENDING state, it
    should call UpdateBotSession to put the leases into the ACTIVE state and
    start executing their assignments.

    All fields in this message are output-only, *except* the `state` and `status`
    fields. Note that repeated fields can only be updated as a unit, so on every
    update the bot must provide an update for *all* the leases the server expects
    it to report on.

    The scheduler *should* ensure that all leases scheduled to a bot can actually
    be accepted, but race conditions may occur. In such cases, the bot should
    attempt to accept the leases in the order they are listed by the server, to
    allow the server to control priorities.

    The server will remove COMPLETED leases from time to time, after which the
    bot shouldn't report on them any more (the server will ignore superfluous
    COMPLETED records).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    RESULT_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    REQUIREMENTS_FIELD_NUMBER: builtins.int
    EXPIRE_TIME_FIELD_NUMBER: builtins.int
    ASSIGNMENT_FIELD_NUMBER: builtins.int
    INLINE_ASSIGNMENT_FIELD_NUMBER: builtins.int
    id: builtins.str
    """A short string uniquely identifing the lease within this bot session."""
    @property
    def payload(self) -> google.protobuf.any_pb2.Any:
        """The actual work to be performed, if any. May be omitted by the server if
        the lease is not in the `PENDING` state. The message must be meaningful to
        the bot. Output only (must only be set by the server).
        """
    @property
    def result(self) -> google.protobuf.any_pb2.Any:
        """Any result the bot wishes to provide about the lease. Must not be changed
        after the first call with the lease in the `COMPLETED` or `CANCELLED`
        state. Input only (must only be set by the bot, will not be echoed by the
        server).
        """
    state: global___LeaseState.ValueType
    """The state of the lease. See LeaseState for more information."""
    @property
    def status(self) -> buildgrid.common.protos.google.rpc.status_pb2.Status:
        """The final status of the lease (should be populated by the bot if the state
        is completed). This is the status of the lease, not of any task represented
        by the lease. For example, if the bot could not accept the lease because it
        asked for some resource the bot didn't have, this status will be
        FAILED_PRECONDITION. But if the assignment in the lease didn't execute
        correctly, this field will be `OK` while the failure of the assignment must
        communicated via the `result` field.
        """
    @property
    def requirements(self) -> buildgrid.common.protos.google.devtools.remoteworkers.v1test2.worker_pb2.Worker:
        """The requirements that are being claimed by this lease. This field may be
        omitted by the server if the lease is not pending.
        """
    @property
    def expire_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The time at which this lease expires. The server *may* extend this over
        time, but due to race conditions, the bot is not *required* to respect any
        expiry date except the first one.
        """
    assignment: builtins.str
    """DEPRECATED. The assignment should be provided to the bot via the `payload`
    field. Clients that wish to use a simple name (such as a queue of work
    provided elsewhere) should define a custom message type and encode it into
    `payload`.
    """
    @property
    def inline_assignment(self) -> google.protobuf.any_pb2.Any:
        """DEPRECATED. Use `payload` instead."""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        payload: google.protobuf.any_pb2.Any | None = ...,
        result: google.protobuf.any_pb2.Any | None = ...,
        state: global___LeaseState.ValueType = ...,
        status: buildgrid.common.protos.google.rpc.status_pb2.Status | None = ...,
        requirements: buildgrid.common.protos.google.devtools.remoteworkers.v1test2.worker_pb2.Worker | None = ...,
        expire_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        assignment: builtins.str = ...,
        inline_assignment: google.protobuf.any_pb2.Any | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["expire_time", b"expire_time", "inline_assignment", b"inline_assignment", "payload", b"payload", "requirements", b"requirements", "result", b"result", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["assignment", b"assignment", "expire_time", b"expire_time", "id", b"id", "inline_assignment", b"inline_assignment", "payload", b"payload", "requirements", b"requirements", "result", b"result", "state", b"state", "status", b"status"]) -> None: ...

global___Lease = Lease

@typing_extensions.final
class AdminTemp(google.protobuf.message.Message):
    """AdminTemp is a prelimiary set of administration tasks. It's called "Temp"
    because we do not yet know the best way to represent admin tasks; it's
    possible that this will be entirely replaced in later versions of this API.
    If this message proves to be sufficient, it will be renamed in the alpha or
    beta release of this API.

    This message (suitably marshalled into a protobuf.Any) can be used as the
    inline_assignment field in a lease; the lease assignment field should simply
    be `"admin"` in these cases.

    This message is heavily based on Swarming administration tasks from the LUCI
    project (http://github.com/luci/luci-py/appengine/swarming).
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Command:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _CommandEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[AdminTemp._Command.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNSPECIFIED: AdminTemp._Command.ValueType  # 0
        """Illegal value."""
        BOT_UPDATE: AdminTemp._Command.ValueType  # 1
        """Download and run a new version of the bot. `arg` will be a resource
        accessible via `ByteStream.Read` to obtain the new bot code.
        """
        BOT_RESTART: AdminTemp._Command.ValueType  # 2
        """Restart the bot without downloading a new version. `arg` will be a
        message to log.
        """
        BOT_TERMINATE: AdminTemp._Command.ValueType  # 3
        """Shut down the bot. `arg` will be a task resource name (similar to those
        in tasks.proto) that the bot can use to tell the server that it is
        terminating.
        """
        HOST_RESTART: AdminTemp._Command.ValueType  # 4
        """Restart the host computer. `arg` will be a message to log."""

    class Command(_Command, metaclass=_CommandEnumTypeWrapper):
        """Possible administration actions."""

    UNSPECIFIED: AdminTemp.Command.ValueType  # 0
    """Illegal value."""
    BOT_UPDATE: AdminTemp.Command.ValueType  # 1
    """Download and run a new version of the bot. `arg` will be a resource
    accessible via `ByteStream.Read` to obtain the new bot code.
    """
    BOT_RESTART: AdminTemp.Command.ValueType  # 2
    """Restart the bot without downloading a new version. `arg` will be a
    message to log.
    """
    BOT_TERMINATE: AdminTemp.Command.ValueType  # 3
    """Shut down the bot. `arg` will be a task resource name (similar to those
    in tasks.proto) that the bot can use to tell the server that it is
    terminating.
    """
    HOST_RESTART: AdminTemp.Command.ValueType  # 4
    """Restart the host computer. `arg` will be a message to log."""

    COMMAND_FIELD_NUMBER: builtins.int
    ARG_FIELD_NUMBER: builtins.int
    command: global___AdminTemp.Command.ValueType
    """The admin action; see `Command` for legal values."""
    arg: builtins.str
    """The argument to the admin action; see `Command` for semantics."""
    def __init__(
        self,
        *,
        command: global___AdminTemp.Command.ValueType = ...,
        arg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["arg", b"arg", "command", b"command"]) -> None: ...

global___AdminTemp = AdminTemp

@typing_extensions.final
class CreateBotSessionRequest(google.protobuf.message.Message):
    """Request message for CreateBotSession."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARENT_FIELD_NUMBER: builtins.int
    BOT_SESSION_FIELD_NUMBER: builtins.int
    parent: builtins.str
    """The farm resource."""
    @property
    def bot_session(self) -> global___BotSession:
        """The bot session to create. Server-assigned fields like name must be unset."""
    def __init__(
        self,
        *,
        parent: builtins.str = ...,
        bot_session: global___BotSession | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["bot_session", b"bot_session"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bot_session", b"bot_session", "parent", b"parent"]) -> None: ...

global___CreateBotSessionRequest = CreateBotSessionRequest

@typing_extensions.final
class UpdateBotSessionRequest(google.protobuf.message.Message):
    """Request message for UpdateBotSession."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    BOT_SESSION_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The bot session name. Must match bot_session.name."""
    @property
    def bot_session(self) -> global___BotSession:
        """The bot session resource to update."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """The fields on the bot that should be updated. See the BotSession resource
        for which fields are updatable by which caller.
        """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        bot_session: global___BotSession | None = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["bot_session", b"bot_session", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bot_session", b"bot_session", "name", b"name", "update_mask", b"update_mask"]) -> None: ...

global___UpdateBotSessionRequest = UpdateBotSessionRequest

@typing_extensions.final
class PostBotEventTempRequest(google.protobuf.message.Message):
    """Request message for PostBotEventTemp"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PostBotEventTempRequest._Type.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNSPECIFIED: PostBotEventTempRequest._Type.ValueType  # 0
        """Illegal value."""
        INFO: PostBotEventTempRequest._Type.ValueType  # 1
        """Interesting but harmless event."""
        ERROR: PostBotEventTempRequest._Type.ValueType  # 2
        """Error condition."""

    class Type(_Type, metaclass=_TypeEnumTypeWrapper):
        """Types of bot events."""

    UNSPECIFIED: PostBotEventTempRequest.Type.ValueType  # 0
    """Illegal value."""
    INFO: PostBotEventTempRequest.Type.ValueType  # 1
    """Interesting but harmless event."""
    ERROR: PostBotEventTempRequest.Type.ValueType  # 2
    """Error condition."""

    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    MSG_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The bot session name."""
    type: global___PostBotEventTempRequest.Type.ValueType
    """The type of bot event."""
    msg: builtins.str
    """A human-readable message."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        type: global___PostBotEventTempRequest.Type.ValueType = ...,
        msg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["msg", b"msg", "name", b"name", "type", b"type"]) -> None: ...

global___PostBotEventTempRequest = PostBotEventTempRequest



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2020 Google LLC

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
import builtins
import buildgrid.common.protos.google.devtools.build.v1.build_status_pb2
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ConsoleOutputStream:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ConsoleOutputStreamEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ConsoleOutputStream.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN: _ConsoleOutputStream.ValueType  # 0
    """Unspecified or unknown."""
    STDOUT: _ConsoleOutputStream.ValueType  # 1
    """Normal output stream."""
    STDERR: _ConsoleOutputStream.ValueType  # 2
    """Error output stream."""

class ConsoleOutputStream(_ConsoleOutputStream, metaclass=_ConsoleOutputStreamEnumTypeWrapper):
    """The type of console output stream."""

UNKNOWN: ConsoleOutputStream.ValueType  # 0
"""Unspecified or unknown."""
STDOUT: ConsoleOutputStream.ValueType  # 1
"""Normal output stream."""
STDERR: ConsoleOutputStream.ValueType  # 2
"""Error output stream."""
global___ConsoleOutputStream = ConsoleOutputStream

@typing_extensions.final
class BuildEvent(google.protobuf.message.Message):
    """An event representing some state change that occurred in the build. This
    message does not include field for uniquely identifying an event.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class InvocationAttemptStarted(google.protobuf.message.Message):
        """Notification that the build system has attempted to run the build tool."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        ATTEMPT_NUMBER_FIELD_NUMBER: builtins.int
        DETAILS_FIELD_NUMBER: builtins.int
        attempt_number: builtins.int
        """The number of the invocation attempt, starting at 1 and increasing by 1
        for each new attempt. Can be used to determine if there is a later
        invocation attempt replacing the current one a client is processing.
        """
        @property
        def details(self) -> google.protobuf.any_pb2.Any:
            """Arbitrary details about the invocation attempt."""
        def __init__(
            self,
            *,
            attempt_number: builtins.int = ...,
            details: google.protobuf.any_pb2.Any | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["details", b"details"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["attempt_number", b"attempt_number", "details", b"details"]) -> None: ...

    @typing_extensions.final
    class InvocationAttemptFinished(google.protobuf.message.Message):
        """Notification that an invocation attempt has finished."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        INVOCATION_STATUS_FIELD_NUMBER: builtins.int
        DETAILS_FIELD_NUMBER: builtins.int
        @property
        def invocation_status(self) -> buildgrid.common.protos.google.devtools.build.v1.build_status_pb2.BuildStatus:
            """Final status of the invocation."""
        @property
        def details(self) -> google.protobuf.any_pb2.Any:
            """Arbitrary details about the invocation attempt."""
        def __init__(
            self,
            *,
            invocation_status: buildgrid.common.protos.google.devtools.build.v1.build_status_pb2.BuildStatus | None = ...,
            details: google.protobuf.any_pb2.Any | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["details", b"details", "invocation_status", b"invocation_status"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["details", b"details", "invocation_status", b"invocation_status"]) -> None: ...

    @typing_extensions.final
    class BuildEnqueued(google.protobuf.message.Message):
        """Notification that the build request is enqueued."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        DETAILS_FIELD_NUMBER: builtins.int
        @property
        def details(self) -> google.protobuf.any_pb2.Any:
            """Additional details about the Build."""
        def __init__(
            self,
            *,
            details: google.protobuf.any_pb2.Any | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["details", b"details"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["details", b"details"]) -> None: ...

    @typing_extensions.final
    class BuildFinished(google.protobuf.message.Message):
        """Notification that the build request has finished, and no further
        invocations will occur.  Note that this applies to the entire Build.
        Individual invocations trigger InvocationFinished when they finish.
        """

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        STATUS_FIELD_NUMBER: builtins.int
        DETAILS_FIELD_NUMBER: builtins.int
        @property
        def status(self) -> buildgrid.common.protos.google.devtools.build.v1.build_status_pb2.BuildStatus:
            """Final status of the build."""
        @property
        def details(self) -> google.protobuf.any_pb2.Any:
            """Additional details about the Build."""
        def __init__(
            self,
            *,
            status: buildgrid.common.protos.google.devtools.build.v1.build_status_pb2.BuildStatus | None = ...,
            details: google.protobuf.any_pb2.Any | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["details", b"details", "status", b"status"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["details", b"details", "status", b"status"]) -> None: ...

    @typing_extensions.final
    class ConsoleOutput(google.protobuf.message.Message):
        """Textual output written to standard output or standard error."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TYPE_FIELD_NUMBER: builtins.int
        TEXT_OUTPUT_FIELD_NUMBER: builtins.int
        BINARY_OUTPUT_FIELD_NUMBER: builtins.int
        type: global___ConsoleOutputStream.ValueType
        """The output stream type."""
        text_output: builtins.str
        """Regular UTF-8 output; normal text."""
        binary_output: builtins.bytes
        """Used if the output is not UTF-8 text (for example, a binary proto)."""
        def __init__(
            self,
            *,
            type: global___ConsoleOutputStream.ValueType = ...,
            text_output: builtins.str = ...,
            binary_output: builtins.bytes = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["binary_output", b"binary_output", "output", b"output", "text_output", b"text_output"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["binary_output", b"binary_output", "output", b"output", "text_output", b"text_output", "type", b"type"]) -> None: ...
        def WhichOneof(self, oneof_group: typing_extensions.Literal["output", b"output"]) -> typing_extensions.Literal["text_output", "binary_output"] | None: ...

    @typing_extensions.final
    class BuildComponentStreamFinished(google.protobuf.message.Message):
        """Notification of the end of a build event stream published by a build
        component other than CONTROLLER (See StreamId.BuildComponents).
        """

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _FinishType:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _FinishTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[BuildEvent.BuildComponentStreamFinished._FinishType.ValueType], builtins.type):  # noqa: F821
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            FINISH_TYPE_UNSPECIFIED: BuildEvent.BuildComponentStreamFinished._FinishType.ValueType  # 0
            """Unknown or unspecified; callers should never set this value."""
            FINISHED: BuildEvent.BuildComponentStreamFinished._FinishType.ValueType  # 1
            """Set by the event publisher to indicate a build event stream is
            finished.
            """
            EXPIRED: BuildEvent.BuildComponentStreamFinished._FinishType.ValueType  # 2
            """Set by the WatchBuild RPC server when the publisher of a build event
            stream stops publishing events without publishing a
            BuildComponentStreamFinished event whose type equals FINISHED.
            """

        class FinishType(_FinishType, metaclass=_FinishTypeEnumTypeWrapper):
            """How did the event stream finish."""

        FINISH_TYPE_UNSPECIFIED: BuildEvent.BuildComponentStreamFinished.FinishType.ValueType  # 0
        """Unknown or unspecified; callers should never set this value."""
        FINISHED: BuildEvent.BuildComponentStreamFinished.FinishType.ValueType  # 1
        """Set by the event publisher to indicate a build event stream is
        finished.
        """
        EXPIRED: BuildEvent.BuildComponentStreamFinished.FinishType.ValueType  # 2
        """Set by the WatchBuild RPC server when the publisher of a build event
        stream stops publishing events without publishing a
        BuildComponentStreamFinished event whose type equals FINISHED.
        """

        TYPE_FIELD_NUMBER: builtins.int
        type: global___BuildEvent.BuildComponentStreamFinished.FinishType.ValueType
        """How the event stream finished."""
        def __init__(
            self,
            *,
            type: global___BuildEvent.BuildComponentStreamFinished.FinishType.ValueType = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["type", b"type"]) -> None: ...

    EVENT_TIME_FIELD_NUMBER: builtins.int
    INVOCATION_ATTEMPT_STARTED_FIELD_NUMBER: builtins.int
    INVOCATION_ATTEMPT_FINISHED_FIELD_NUMBER: builtins.int
    BUILD_ENQUEUED_FIELD_NUMBER: builtins.int
    BUILD_FINISHED_FIELD_NUMBER: builtins.int
    CONSOLE_OUTPUT_FIELD_NUMBER: builtins.int
    COMPONENT_STREAM_FINISHED_FIELD_NUMBER: builtins.int
    BAZEL_EVENT_FIELD_NUMBER: builtins.int
    BUILD_EXECUTION_EVENT_FIELD_NUMBER: builtins.int
    SOURCE_FETCH_EVENT_FIELD_NUMBER: builtins.int
    @property
    def event_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The timestamp of this event."""
    @property
    def invocation_attempt_started(self) -> global___BuildEvent.InvocationAttemptStarted:
        """An invocation attempt has started."""
    @property
    def invocation_attempt_finished(self) -> global___BuildEvent.InvocationAttemptFinished:
        """An invocation attempt has finished."""
    @property
    def build_enqueued(self) -> global___BuildEvent.BuildEnqueued:
        """The build is enqueued."""
    @property
    def build_finished(self) -> global___BuildEvent.BuildFinished:
        """The build has finished. Set when the build is terminated."""
    @property
    def console_output(self) -> global___BuildEvent.ConsoleOutput:
        """An event containing printed text."""
    @property
    def component_stream_finished(self) -> global___BuildEvent.BuildComponentStreamFinished:
        """Indicates the end of a build event stream (with the same StreamId) from
        a build component executing the requested build task.
        *** This field does not indicate the WatchBuild RPC is finished. ***
        """
    @property
    def bazel_event(self) -> google.protobuf.any_pb2.Any:
        """Structured build event generated by Bazel about its execution progress."""
    @property
    def build_execution_event(self) -> google.protobuf.any_pb2.Any:
        """An event that contains supplemental tool-specific information about
        build execution.
        """
    @property
    def source_fetch_event(self) -> google.protobuf.any_pb2.Any:
        """An event that contains supplemental tool-specific information about
        source fetching.
        """
    def __init__(
        self,
        *,
        event_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        invocation_attempt_started: global___BuildEvent.InvocationAttemptStarted | None = ...,
        invocation_attempt_finished: global___BuildEvent.InvocationAttemptFinished | None = ...,
        build_enqueued: global___BuildEvent.BuildEnqueued | None = ...,
        build_finished: global___BuildEvent.BuildFinished | None = ...,
        console_output: global___BuildEvent.ConsoleOutput | None = ...,
        component_stream_finished: global___BuildEvent.BuildComponentStreamFinished | None = ...,
        bazel_event: google.protobuf.any_pb2.Any | None = ...,
        build_execution_event: google.protobuf.any_pb2.Any | None = ...,
        source_fetch_event: google.protobuf.any_pb2.Any | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["bazel_event", b"bazel_event", "build_enqueued", b"build_enqueued", "build_execution_event", b"build_execution_event", "build_finished", b"build_finished", "component_stream_finished", b"component_stream_finished", "console_output", b"console_output", "event", b"event", "event_time", b"event_time", "invocation_attempt_finished", b"invocation_attempt_finished", "invocation_attempt_started", b"invocation_attempt_started", "source_fetch_event", b"source_fetch_event"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bazel_event", b"bazel_event", "build_enqueued", b"build_enqueued", "build_execution_event", b"build_execution_event", "build_finished", b"build_finished", "component_stream_finished", b"component_stream_finished", "console_output", b"console_output", "event", b"event", "event_time", b"event_time", "invocation_attempt_finished", b"invocation_attempt_finished", "invocation_attempt_started", b"invocation_attempt_started", "source_fetch_event", b"source_fetch_event"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["event", b"event"]) -> typing_extensions.Literal["invocation_attempt_started", "invocation_attempt_finished", "build_enqueued", "build_finished", "console_output", "component_stream_finished", "bazel_event", "build_execution_event", "source_fetch_event"] | None: ...

global___BuildEvent = BuildEvent

@typing_extensions.final
class StreamId(google.protobuf.message.Message):
    """Unique identifier for a build event stream."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _BuildComponent:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _BuildComponentEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[StreamId._BuildComponent.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN_COMPONENT: StreamId._BuildComponent.ValueType  # 0
        """Unknown or unspecified; callers should never set this value."""
        CONTROLLER: StreamId._BuildComponent.ValueType  # 1
        """A component that coordinates builds."""
        WORKER: StreamId._BuildComponent.ValueType  # 2
        """A component that runs executables needed to complete a build."""
        TOOL: StreamId._BuildComponent.ValueType  # 3
        """A component that builds something."""

    class BuildComponent(_BuildComponent, metaclass=_BuildComponentEnumTypeWrapper):
        """Which build component generates this event stream. Each build component
        may generate one event stream.
        """

    UNKNOWN_COMPONENT: StreamId.BuildComponent.ValueType  # 0
    """Unknown or unspecified; callers should never set this value."""
    CONTROLLER: StreamId.BuildComponent.ValueType  # 1
    """A component that coordinates builds."""
    WORKER: StreamId.BuildComponent.ValueType  # 2
    """A component that runs executables needed to complete a build."""
    TOOL: StreamId.BuildComponent.ValueType  # 3
    """A component that builds something."""

    BUILD_ID_FIELD_NUMBER: builtins.int
    INVOCATION_ID_FIELD_NUMBER: builtins.int
    COMPONENT_FIELD_NUMBER: builtins.int
    build_id: builtins.str
    """The id of a Build message."""
    invocation_id: builtins.str
    """The unique invocation ID within this build.
    It should be the same as {invocation} (below) during the migration.
    """
    component: global___StreamId.BuildComponent.ValueType
    """The component that emitted this event."""
    def __init__(
        self,
        *,
        build_id: builtins.str = ...,
        invocation_id: builtins.str = ...,
        component: global___StreamId.BuildComponent.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["build_id", b"build_id", "component", b"component", "invocation_id", b"invocation_id"]) -> None: ...

global___StreamId = StreamId
